@@ -7,4 +7,4 @@
        -v /usr/local/share/ca-certificates:/usr/local/share/ca-certificates:ro \
        -v /var/run/docker.sock:/var/run/docker.sock \
        --entrypoint enough \
-       {{ this.registry }}enough{{ this.version }} "$@"
+       {{ this.registry }}enough{{ this.tag }} "$@"
