@@ -5,7 +5,7 @@ def test_resolvconf(host):
     resolvconf_before = host.run("cat /etc/resolv.conf").stdout.strip()
     with host.sudo():
         host.run("""
-        for i in eth0 eth1 enp1s0 enp2s0 ; do
+        for i in eth0 eth1 ens3 ens7 enp1s0 enp2s0 ; do
           ifdown $i
           ifup $i
         done
